"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const directions_1 = require("../directions");
const trie_1 = require("./trie");
function findMatches(rows, words, directions = directions_1.Directions) {
    const trie = new trie_1.TrieNode();
    for (const word of words) {
        trie.add(word);
    }
    const matches = [];
    for (let startRowIdx = 0; startRowIdx < rows.length; startRowIdx++) {
        const row = rows[startRowIdx];
        for (let startColIdx = 0; startColIdx < row.length; startColIdx++) {
            for (const direction of directions) {
                let rowIdx = startRowIdx;
                let colIdx = startColIdx;
                let seen = "";
                while (rowIdx >= 0 &&
                    rowIdx < rows.length &&
                    colIdx >= 0 &&
                    colIdx < rows[rowIdx].length) {
                    seen += rows[rowIdx][colIdx];
                    const result = trie.isPrefix(seen);
                    if (result === null) {
                        break;
                    }
                    if (result.isComplete) {
                        matches.push({
                            word: seen,
                            start: { rowIdx: startRowIdx, colIdx: startColIdx },
                            end: { rowIdx, colIdx }
                        });
                    }
                    if (!result.hasMore) {
                        break;
                    }
                    rowIdx += direction.rowIdx;
                    colIdx += direction.colIdx;
                }
            }
        }
    }
    return matches;
}
exports.findMatches = findMatches;
//# sourceMappingURL=prefix.js.map